==> qtjambi-qt3dcore-debuginfo-linux-x64-5.15.17.jar: sources/QtJambi3DCore/QAspectJob_shell.cpp <==
#include "QAspectJob_shell.h"
#include <QtJambi/Cast>

void deleter_Qt3DCore_QAspectJob(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QAspectJob")
    Qt3DCore::QAspectJob *_ptr = reinterpret_cast<Qt3DCore::QAspectJob *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAspectJob_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAspectJob_shell) ); }

jmethodID QAspectJob_shell::__shell_javaMethod(int pos) const { return QAspectJob_shell::__shell()->javaMethod(typeid(Qt3DCore::QAspectJob), pos); }

// emitting (writeShellConstructor)
QAspectJob_shell::QAspectJob_shell()
    : Qt3DCore::QAspectJob()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DCore::QAspectJob::QAspectJob_shell()", QAspectJob_shell::__shell())
    QAspectJob_shell::__shell()->constructed(typeid(Qt3DCore::QAspectJob));
}

// emitting (writeShellDestructor)
QAspectJob_shell::~QAspectJob_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DCore::QAspectJob::~Qt3DCore::QAspectJob()", QAspectJob_shell::__shell())
    QAspectJob_shell::__shell()->destructed(typeid(Qt3DCore::QAspectJob));
}

void QAspectJob_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAspectJob_shell*>(ptr)->QAspectJob_shell::__shell()->tryDeleteShell(typeid(Qt3DCore::QAspectJob));
}

// emitting Virtual overrides (virtualFunctions)
void QAspectJob_shell::run()
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("Qt3DCore::QAspectJob::run()", QAspectJob_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAspectJob_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAspectJob_shell::__shell()->warnForMethod("Qt3DCore::QAspectJob::run()");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "Qt3DCore::QAspectJob::run()");
            } QTJAMBI_TRY_END
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QAspectJob_access::__qt_run(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method Qt3DCore::QAspectJob::run()." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method Qt3DCore::QAspectJob::run().";
    } else {
        run();
    }
}

// emitting (writeConstructors)
// new QAspectJob()
void __qt_construct_Qt3DCore_QAspectJob_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAspectJob()")
    Q_UNUSED(__java_arguments)
    Qt3DCore::QAspectJob *__qt_this = new(__qtjambi_ptr) QAspectJob_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QAspectJob_shell
void __qt_destruct_Qt3DCore_QAspectJob(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QAspectJob")
    reinterpret_cast<QAspectJob_shell*>(ptr)->~QAspectJob_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DCore::QAspectJob::QAspectJob()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QAspectJob_initialize_1native__Lio_qt_qt3d_core_QAspectJob_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QAspectJob::QAspectJob()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QAspectJob_0, sizeof(QAspectJob_shell), typeid(Qt3DCore::QAspectJob), true, &deleter_Qt3DCore_QAspectJob, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DCore::QAspectJob::addDependency(QWeakPointer<Qt3DCore::QAspectJob>)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QAspectJob_addDependency_1native_1QWeakPointer__JLio_qt_qt3d_core_QAspectJob_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject dependency0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        Qt3DCore::QAspectJob *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QAspectJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QAspectJob::addDependency(QWeakPointer<Qt3DCore::QAspectJob>)", __qt_this)
        QWeakPointer<Qt3DCore::QAspectJob> __qt_dependency0 = qtjambi_cast<QWeakPointer<Qt3DCore::QAspectJob> >(__jni_env, __qtjambi_scope, dependency0);
        __qt_this->addDependency(__qt_dependency0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DCore::QAspectJob::dependencies()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QAspectJob_dependencies_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QAspectJob *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QAspectJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QAspectJob::dependencies()const", __qt_this)
        QVector<QWeakPointer<Qt3DCore::QAspectJob>> __qt_return_value = __qt_this->dependencies();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QAspectJob::removeDependency(QWeakPointer<Qt3DCore::QAspectJob>)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QAspectJob_removeDependency_1native_1QWeakPointer__JLio_qt_qt3d_core_QAspectJob_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject dependency0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        Qt3DCore::QAspectJob *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QAspectJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QAspectJob::removeDependency(QWeakPointer<Qt3DCore::QAspectJob>)", __qt_this)
        QWeakPointer<Qt3DCore::QAspectJob> __qt_dependency0 = qtjambi_cast<QWeakPointer<Qt3DCore::QAspectJob> >(__jni_env, __qtjambi_scope, dependency0);
        __qt_this->removeDependency(__qt_dependency0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DCore::QAspectJob::run()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QAspectJob_00024ConcreteWrapper_run_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        Qt3DCore::QAspectJob *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QAspectJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QAspectJob::run()", __qt_this)
        static_cast<QAspectJob_access*>(__qt_this)->__qt_run(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DCore_QAspectJob(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<Qt3DCore::QAspectJob>("Qt3DCore::QAspectJob", "io/qt/qt3d/core/QAspectJob");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "run", "()V", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QAspectJob, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QAspectJob_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QAspectJob);
    registerSizeOfShell(typeId, sizeof(QAspectJob_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qt3dcore-debuginfo-linux-x64-5.15.20.jar: sources/QtJambi3DCore/QAspectJob_shell.cpp <==
#include "QAspectJob_shell.h"
#include <QtJambi/Cast>

void deleter_Qt3DCore_QAspectJob(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QAspectJob")
    Qt3DCore::QAspectJob *_ptr = reinterpret_cast<Qt3DCore::QAspectJob *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAspectJob_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAspectJob_shell) ); }

jmethodID QAspectJob_shell::__shell_javaMethod(int pos) const { return QAspectJob_shell::__shell()->javaMethod(typeid(Qt3DCore::QAspectJob), pos); }

// emitting (writeShellConstructor)
QAspectJob_shell::QAspectJob_shell()
    : Qt3DCore::QAspectJob()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DCore::QAspectJob::QAspectJob_shell()", QAspectJob_shell::__shell())
    QAspectJob_shell::__shell()->constructed(typeid(Qt3DCore::QAspectJob));
}

// emitting (writeShellDestructor)
QAspectJob_shell::~QAspectJob_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DCore::QAspectJob::~Qt3DCore::QAspectJob()", QAspectJob_shell::__shell())
    QAspectJob_shell::__shell()->destructed(typeid(Qt3DCore::QAspectJob));
}

void QAspectJob_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAspectJob_shell*>(ptr)->QAspectJob_shell::__shell()->tryDeleteShell(typeid(Qt3DCore::QAspectJob));
}

// emitting Virtual overrides (virtualFunctions)
void QAspectJob_shell::run()
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("Qt3DCore::QAspectJob::run()", QAspectJob_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAspectJob_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAspectJob_shell::__shell()->warnForMethod("Qt3DCore::QAspectJob::run()");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "Qt3DCore::QAspectJob::run()");
            } QTJAMBI_TRY_END
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QAspectJob_access::__qt_run(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method Qt3DCore::QAspectJob::run()." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method Qt3DCore::QAspectJob::run().";
    } else {
        run();
    }
}

// emitting (writeConstructors)
// new QAspectJob()
void __qt_construct_Qt3DCore_QAspectJob(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAspectJob()")
    Q_UNUSED(__java_arguments)
    Qt3DCore::QAspectJob *__qt_this = new(__qtjambi_ptr) QAspectJob_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// Qt3DCore::QAspectJob::QAspectJob()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QAspectJob_initialize_1native__Lio_qt_qt3d_core_QAspectJob_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QAspectJob::QAspectJob()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QAspectJob, sizeof(QAspectJob_shell), typeid(Qt3DCore::QAspectJob), true, &deleter_Qt3DCore_QAspectJob, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QAspectJob_shell
void __qt_destruct_Qt3DCore_QAspectJob(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QAspectJob")
    reinterpret_cast<QAspectJob_shell*>(ptr)->~QAspectJob_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DCore::QAspectJob::addDependency(QWeakPointer<Qt3DCore::QAspectJob>)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QAspectJob_addDependency_1native_1QWeakPointer__JLio_qt_qt3d_core_QAspectJob_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject dependency0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        Qt3DCore::QAspectJob *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QAspectJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QAspectJob::addDependency(QWeakPointer<Qt3DCore::QAspectJob>)", __qt_this)
        QWeakPointer<Qt3DCore::QAspectJob> __qt_dependency0 = qtjambi_cast<QWeakPointer<Qt3DCore::QAspectJob> >(__jni_env, __qtjambi_scope, dependency0);
        __qt_this->addDependency(__qt_dependency0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DCore::QAspectJob::dependencies()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QAspectJob_dependencies_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DCore::QAspectJob *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QAspectJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QAspectJob::dependencies()const", __qt_this)
        QVector<QWeakPointer<Qt3DCore::QAspectJob>> __qt_return_value = __qt_this->dependencies();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DCore::QAspectJob::removeDependency(QWeakPointer<Qt3DCore::QAspectJob>)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QAspectJob_removeDependency_1native_1QWeakPointer__JLio_qt_qt3d_core_QAspectJob_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject dependency0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        Qt3DCore::QAspectJob *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QAspectJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QAspectJob::removeDependency(QWeakPointer<Qt3DCore::QAspectJob>)", __qt_this)
        QWeakPointer<Qt3DCore::QAspectJob> __qt_dependency0 = qtjambi_cast<QWeakPointer<Qt3DCore::QAspectJob> >(__jni_env, __qtjambi_scope, dependency0);
        __qt_this->removeDependency(__qt_dependency0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DCore::QAspectJob::run()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QAspectJob_00024ConcreteWrapper_run_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        Qt3DCore::QAspectJob *__qt_this = QtJambiAPI::objectFromNativeId<Qt3DCore::QAspectJob>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DCore::QAspectJob::run()", __qt_this)
        static_cast<QAspectJob_access*>(__qt_this)->__qt_run(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DCore_QAspectJob(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<Qt3DCore::QAspectJob>("Qt3DCore::QAspectJob", "io/qt/qt3d/core/QAspectJob");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "run", "()V", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QAspectJob, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QAspectJob, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QAspectJob);
    registerSizeOfShell(typeId, sizeof(QAspectJob_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
